==> ktp-common-internals-0.6.80.tar.bz2: ktp-common-internals-0.6.80/KTp/Logger/plugins/tplogger/ktploggerplugin_tplogger.desktop.cmake <==
[Desktop Entry]
Name=Telepathy Logger plugin
Name[ca]=Connector de registre del Telepathy
Name[cs]=Modul záznamů Telepathy
Name[da]=Logger-plugin til Telepathy
Name[es]=Complemento de gestor de registro de Telepathy
Name[fi]=Telepathy Logger -liitännäinen
Name[fr]=Module externe de journalisation de Telepathy
Name[it]=Estensione di Telepathy Logger
Name[nb]=Telepathy logger-modul
Name[nl]=Telepathy Logger-plug-in
Name[pt]='Plugin' de Registo do Telepathy
Name[pt_BR]=Plugin do Telepathy Logger
Name[sk]=Plugin Telepathy záznam
Name[sl]=Vstavek za beleženje za Telepathy
Name[sr]=Телепатијски прикључак бележника
Name[sr@ijekavian]=Телепатијски прикључак бележника
Name[sr@ijekavianlatin]=Telepathy priključak beležnika
Name[sr@latin]=Telepathy priključak beležnika
Name[sv]=Telepathy-loggningsinsticksprogram
Name[uk]=Додаток ведення журналу Telepathy
Name[x-test]=xxTelepathy Logger pluginxx
Name[zh_TW]=Telepathy 紀錄器外掛程式
Comment=Provides integration with Telepathy Logger
Comment[ca]=Aquest connector proporciona integració amb l'enregistrador del Telepathy
Comment[cs]=Poskytuje integraci se zaznamenáváním Telepathy
Comment[da]=Giver integration med Telepathy Logger
Comment[es]=Proporciona integración con el gestor de registro de Telepathy
Comment[fi]=Tarjoaa integraation Telepathy Loggerille
Comment[fr]=Fournit une intégration avec la journalisation de Telepathy
Comment[it]=Fornisce integrazione con Telepathy Logger
Comment[nb]=Skaffer integrering med Telepathy logger
Comment[nl]=Biedt integratie met Telepathy Logger
Comment[pt]=Oferece a integração com o sistema de registo Telepathy Logger
Comment[pt_BR]=Fornece integração com o Telepathy Logger
Comment[sk]=Poskytuje integráciu so záznamom Telepathy
Comment[sl]=Omogoča podpora za beleženje za Telepathy
Comment[sr]=Пружа интеграцију са телепатијским прикључком бележника
Comment[sr@ijekavian]=Пружа интеграцију са телепатијским прикључком бележника
Comment[sr@ijekavianlatin]=Pruža integraciju sa Telepathy priključkom beležnika
Comment[sr@latin]=Pruža integraciju sa Telepathy priključkom beležnika
Comment[sv]=Tillhandahåller integrering med Telepathy-loggningsinsticksprogram
Comment[uk]=Забезпечує інтеграцію з засобом ведення журналу Telepathy
Comment[x-test]=xxProvides integration with Telepathy Loggerxx
Comment[zh_TW]=提供 Telepathy 紀錄器的整合

ServiceTypes=KTpLogger/Plugin

X-KDE-Library=ktploggerplugin_tplogger
X-KDE-PluginInfo-Author=Daniel Vrátil
X-KDE-PluginInfo-Email=dvratil@redhat.com
X-KDE-PluginInfo-Name=tplogger
X-KDE-PluginInfo-Version=@KTP_COMMON_INTERNALS_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KTp-PluginInfo-Version=@KTP_LOGGER_PLUGIN_VERSION@
Encoding=UTF-8
Type=Service

==> ktp-common-internals-0.7.0.tar.bz2: ktp-common-internals-0.7.0/KTp/Logger/plugins/tplogger/ktploggerplugin_tplogger.desktop.cmake <==
[Desktop Entry]
Name=Telepathy Logger plugin
Name[bs]=Telepathy dnevnički dodatak
Name[ca]=Connector de registre del Telepathy
Name[ca@valencia]=Connector de registre del Telepathy
Name[cs]=Modul záznamů Telepathy
Name[da]=Logger-plugin til Telepathy
Name[de]=Telepathy-Protokollmodul
Name[es]=Complemento de gestor de registro de Telepathy
Name[fi]=Telepathy Logger -liitännäinen
Name[fr]=Module externe de journalisation de Telepathy
Name[hu]=Telepathy naplózó bővítmény
Name[ia]=Plugin de Telepathy Logger
Name[it]=Estensione di Telepathy Logger
Name[kk]=Telepathy журналын жүргізу плагині
Name[nl]=Telepathy Logger-plug-in
Name[pt]='Plugin' de Registo do Telepathy
Name[pt_BR]=Plugin do Telepathy Logger
Name[ru]=Модуль ведения журналов Telepathy
Name[sk]=Plugin Telepathy záznam
Name[sl]=Vstavek za beleženje za Telepathy
Name[sr]=Телепатијски прикључак бележника
Name[sr@ijekavian]=Телепатијски прикључак бележника
Name[sr@ijekavianlatin]=Telepathy priključak beležnika
Name[sr@latin]=Telepathy priključak beležnika
Name[sv]=Telepathy-loggningsinsticksprogram
Name[tr]=Telepathy Günlükleme eklentisi
Name[uk]=Додаток ведення журналу Telepathy
Name[x-test]=xxTelepathy Logger pluginxx
Name[zh_CN]=Telepathy 日志插件
Name[zh_TW]=Telepathy 紀錄器外掛程式
Comment=Provides integration with Telepathy Logger
Comment[bs]=Obavlja integraciju s Telepathy dnevnikom
Comment[ca]=Proporciona integració amb l'enregistrador del Telepathy
Comment[ca@valencia]=Proporciona integració amb l'enregistrador del Telepathy
Comment[cs]=Poskytuje integraci se zaznamenáváním Telepathy
Comment[da]=Giver integration med Telepathy Logger
Comment[de]=Stellt Integration mit Telepathy-Protokollen zur Verfügung
Comment[es]=Proporciona integración con el gestor de registro de Telepathy
Comment[fi]=Tarjoaa integraation Telepathy Loggerille
Comment[fr]=Fournit une intégration avec la journalisation de Telepathy
Comment[hu]=Integrációt biztosít a Telepathy naplózóval
Comment[ia]=Il provide integration con Telepathy Logger
Comment[it]=Fornisce integrazione con Telepathy Logger
Comment[kk]=Telepathy журнал жүргізумен біріктіруін қамтамасыз ету
Comment[nl]=Biedt integratie met Telepathy Logger
Comment[pt]=Oferece a integração com o sistema de registo Telepathy Logger
Comment[pt_BR]=Fornece integração com o Telepathy Logger
Comment[ru]=Обеспечивает интеграцию журналов Telepathy
Comment[sk]=Poskytuje integráciu so záznamom Telepathy
Comment[sl]=Omogoča podporo za beleženje za Telepathy
Comment[sr]=Пружа интеграцију са телепатијским прикључком бележника
Comment[sr@ijekavian]=Пружа интеграцију са телепатијским прикључком бележника
Comment[sr@ijekavianlatin]=Pruža integraciju sa Telepathy priključkom beležnika
Comment[sr@latin]=Pruža integraciju sa Telepathy priključkom beležnika
Comment[sv]=Tillhandahåller integrering med Telepathy-loggningsinsticksprogram
Comment[tr]=Telephaty Günlükleme ile bütünleştirme sağlar
Comment[uk]=Забезпечує інтеграцію з засобом ведення журналу Telepathy
Comment[x-test]=xxProvides integration with Telepathy Loggerxx
Comment[zh_CN]=提供与 Telepathy 日志的集成
Comment[zh_TW]=提供與 Telepathy 紀錄器的整合

ServiceTypes=KTpLogger/Plugin

X-KDE-Library=ktploggerplugin_tplogger
X-KDE-PluginInfo-Author=Daniel Vrátil
X-KDE-PluginInfo-Email=dvratil@redhat.com
X-KDE-PluginInfo-Name=tplogger
X-KDE-PluginInfo-Version=@KTP_COMMON_INTERNALS_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KTp-PluginInfo-Version=@KTP_LOGGER_PLUGIN_VERSION@
Encoding=UTF-8
Type=Service
